@@ -19,7 +19,7 @@ struct duc_graph_backend {
 	void (*free)(duc_graph *g);
 	void (*start)(duc_graph *g);
 	void (*draw_tooltip)(duc_graph *g, double x, double y, char *text);
-	void (*draw_section)(duc_graph *g, double a1, double a2, double r1, double r2, double H, double S, double V, double line);
+	void (*draw_section)(duc_graph *g, double a1, double a2, double r1, double r2, double R, double G, double B, double line);
 	void (*draw_text)(duc_graph *g, double x, double y, double size, char *text);
 	void (*done)(duc_graph *g);
 };
@@ -66,6 +66,5 @@ duc_graph *duc_graph_new(duc *duc);
 double ang(double a);
 void pol2car(duc_graph *g, double a, double r, double *x, double *y);
 void car2pol(duc_graph *g, double x, double y, double *a, double *r);
-void hsv2rgb(double h, double s, double v, double *r, double *g, double *b);
 
 #endif
